===========
File Upload
===========

File upload functionality is accessed through the +modify item view or the
Index view.

To upload a file on the +modify item view, click the browser's Browse/Choose
button. Use the browser's file dialog to select an item, then click the OK button.
The file will be uploaded and saved with the previously chosen content type;
file name suffixes are ignored.

To upload a file or files on the global index navigation view,
start by clicking the `New Item` link to bring the `Create new item` dialog
into view.

From the Index view, there are two methods of uploading files: single file or multiple files.
Uploaded files will be logically placed within the current index, sub-index, or namespace.
Multiple file uploads have several restrictions:

 * the files will be uploaded and saved using the current name
 * existing items with the same name will be overwritten
 * the file names should have a valid suffix that defines the file type
 * files without a known suffix will be stored as-is and available for download

Single File Upload
==================

Enter the new item name into the input area
and click the `Create` button. Select the content type to proceed to the +modify view.
Use the browser's file dialog to select an item, then click the OK button.
The file will be uploaded and saved with the chosen content type;
file name suffixes are ignored.


Multiple File Upload
====================

Click the browser's Browse/Choose button and select one or more files from the browser's
file dialog, or use the drag-and-drop method to copy files.

The file uploads will start immediately. Upload status will be displayed by
overall and individual progress bars. The names of the files successfully uploaded will be
prepended to the list of files in the index.
